@@ -44,8 +44,16 @@
 #'
 
 mag <- function (data, n = 60, dt0 = NULL, inter_gap = 45, tz = "") {
+
   mag_single <- function (data) {
     data_ip = CGMS2DayByDay(data, dt0 = dt0, inter_gap = inter_gap, tz = tz)
+    dt0 <- data_ip[[3]]
+    if (n < dt0) {
+      message(paste("Parameter n cannot be less than the data collection frequency: " ,
+                    dt0, " , function will be evaluated with n = ", dt0, sep = ""))
+      n <- dt0
+    }
+
     idx = seq(1, ncol(data_ip[[1]]), by = round(n/data_ip[[3]]))
     idx_gl = as.vector(t(data_ip[[1]][, idx]))
     mag = sum(abs(diff(idx_gl)), na.rm = TRUE)/
@@ -57,6 +65,12 @@ mag <- function (data, n = 60, dt0 = NULL, inter_gap = 45, tz = "") {
   rm(list = c("id", "mag"))
   data = check_data_columns(data)
 
+  if (!is.integer(n)) {
+    n <- round(n)
+    message("Parameter n must be an integer, input has been rounded to nearest
+            integer")
+  }
+
   out = data %>%
     dplyr::group_by(id) %>%
     dplyr::summarise(
